@@ -105,10 +105,10 @@ impl AdultLiveness {
     pub fn record_adult_read_liveness(
         &mut self,
         correlation_id: MessageId,
-        src: XorName,
+        src: &XorName,
         success: bool,
     ) -> Option<(BlobAddress, EndUser)> {
-        self.remove_target(correlation_id, &src);
+        self.remove_target(correlation_id, src);
         let op = self.ops.get_mut(&correlation_id);
         op.and_then(|op| {
             let ReadOperation {
@@ -141,9 +141,10 @@ impl AdultLiveness {
         let closest_adults_collection = self
             .closest_adults
             .iter()
-            .map(|(key, value)| {
-                let closest_adults = value
-                    .iter()
+            .map(|(key, _)| {
+                let closest_adults = self
+                    .closest_adults
+                    .keys()
                     .filter(|name| key != *name)
                     .sorted_by(|lhs, rhs| key.cmp_distance(lhs, rhs))
                     .take(NEIGHBOUR_COUNT)
